@@ -11,7 +11,7 @@ from typing import Collection, List, NamedTuple, Optional, Set, Union
 
 MAX_PYTHON_1_VERSION = 6  # i.e. 1.6
 MAX_PYTHON_2_VERSION = 7  # i.e. 2.7
-CURRENT_PYTHON_3_VERSION = 9  # i.e. 3.9
+CURRENT_PYTHON_3_VERSION = 11  # i.e. 3.10
 
 MAX_MINOR_FOR_MAJOR = {
     1: MAX_PYTHON_1_VERSION,
@@ -89,7 +89,11 @@ def is_important(v: Union[Version, str]) -> bool:
     upcoming_release = Version(major=3, minor=CURRENT_PYTHON_3_VERSION + 1)
     return (
         not v.prefix.startswith(('PyPy', 'Jython')) and v.prefix != 'nightly'
-        and not v.suffix.endswith('-dev') and v != upcoming_release
+        and '-dev' not in v.suffix
+        and '-alpha' not in v.suffix
+        and '-beta' not in v.suffix
+        and '-rc' not in v.suffix
+        and v != upcoming_release
     )
 
 
@@ -113,6 +117,14 @@ def pypy_versions(versions: Collection[Version]) -> VersionSet:
 
 
 def expand_pypy(versions: Collection[Version]) -> SortedVersionList:
+    """Determine whether PyPy support means PyPy2 or PyPy3 or both.
+
+    Some data sources (like setup.py classifiers) allow you to indicate PyPy
+    support without specifying whether you mean PyPy2 or PyPy3.  Other data
+    sources (like all CI systems) are more explicit.  To make these version
+    lists directly comparable we need to look at supported CPython versions and
+    translate that knowledge into PyPy versions.
+    """
     supports_pypy = any(v.prefix == 'PyPy' for v in versions)
     if not supports_pypy:
         return sorted(versions)
